
/*
 * cryptofs.h -- definitions for the cryptofshar module
 *
 * cryptofsopyright (C) 2001 Alessandro Rubini and Jonathan Corbet
 * Copyright (C) 2001 O'Reilly & Associates
 *
 * The source code in this file can be freely used, adapted,
 * and redistributed in source or binary form, so long as an
 * acknowledgment appears in derived source files.  The citation
 * should list that the code comes from the book "Linux Device
 * Drivers" by Alessandro Rubini and Jonathan Corbet, published
 * by O'Reilly & Associates.   No warranty is attached;
 * we cannot take responsibility for errors or fitness for use.
 *
 */


#include <linux/ioctl.h>

/* version dependencies have been confined to a separate file */

#include "sysdep.h"

/* Multiqueue only works on 2.4 */
#ifdef cryptofs_MULTIQUEUE
#  ifndef LINUX_24
#    warning "Multiqueue only works on 2.4 kernels"
#    undef cryptofs_MULTIQUEUE
#  endif
#endif

/*
 * Macros to help debugging
 */

#undef PDEBUG             /* undef it, just in case */
#ifdef cryptofs_DEBUG
#  ifdef __KERNEL__
     /* This one if debugging is on, and kernel space */
#    define PDEBUG(fmt, args...) printk( KERN_DEBUG "cryptofs: " fmt, ## args)
#  else
     /* This one for user space */
#    define PDEBUG(fmt, args...) fprintf(stderr, fmt, ## args)
#  endif
#else
#  define PDEBUG(fmt, args...) /* not debugging: nothing */
#endif

#undef PDEBUGG
#define PDEBUGG(fmt, args...) /* nothing: it's a placeholder */


#define cryptofs_MAJOR 0       /* dynamic major by default */
#define cryptofs_DEVS 2        /* two disks */
#define cryptofs_RAHEAD 2      /* two sectors */
#define cryptofs_SIZE 2048     /* two megs each */
#define cryptofs_BLKSIZE 1024  /* 1k blocks */
#define cryptofs_HARDSECT 512  /* 2.2 and 2.4 can used different values */

#define cryptofsR_MAJOR 0      /* Dynamic major for raw device */
/*
 * The c device is removable: if it is left closed for more than
 * half a minute, it is removed. Thus use a usage count and a
 * kernel timer
 */

struct attribute
{
 char* filename;
 char* key;
 int size;
};


typedef struct cryptofs_Dev {
   char* key;
   char* filename;
   int fd;
   int size;
   int usage;
   struct timer_list timer;
   spinlock_t lock;
   u8 *data;
#ifdef cryptofs_MULTIQUEUE
   request_queue_t queue;
   int busy;
#endif
}              cryptofs_Dev;
